/*
 * Example for MCP1664 click
 *
 * Date         Apr 2017
 * Author       Danilo Milovic
 *
 * Test configuration PIC :
 *  MCU           :        STM32F107VC
 *  Dev. Board    :        EasyMx PRO for STM v7
 *  SW            :        mikroC PRO for ARM v5.0.0
 *
 * Description :
 * Place MCP1664 click in mikroBus socket 1
 * This example shows basic control of light brightness with PWM,
 * duty cycle is controled with potentiometer P1, jumper J4 needs to be set on A3
 * CAUTION: Do not look directly at LED's.
 ******************************************************************************/


  /*****************************************************************************
  * Includes
  *****************************************************************************/

  #include "built_in.h"

  /*****************************************************************************
  * Module Variable Definitions
  *****************************************************************************/
  unsigned int current_duty;
  unsigned int pwm_period1;
  unsigned long adc_result;
  char txt[12];





  void MCU_Init()
  {
    // Configure PORTA pins as input
    GPIO_Digital_Input (&GPIOA_BASE,
                        _GPIO_PINMASK_3 |
                        _GPIO_PINMASK_4 |
                        _GPIO_PINMASK_5 |
                        _GPIO_PINMASK_6);
       GPIO_Digital_Output(&GPIOA_BASE,_GPIO_PINMASK_0);
    ADC_Set_Input_Channel(_ADC_CHANNEL_3);                                // Choose ADC channel
    ADC1_Init();                                                          // ADC Init
    Delay_ms(100);
    pwm_period1 = PWM_TIM2_Init(10000);
    PWM_TIM2_Set_Duty(current_duty,  _PWM_NON_INVERTED, _PWM_CHANNEL1);   // Set current duty for PWM_TIM2
    PWM_TIM2_Start(_PWM_CHANNEL1, &_GPIO_MODULE_TIM2_CH1_PA0);
  }

  void main()
  {

   MCU_Init();

   while(1)
   {
     adc_result = ADC1_Get_Sample(3);
     Delay_ms(1);
     PWM_TIM2_Set_Duty(adc_result,  _PWM_NON_INVERTED, _PWM_CHANNEL1);

   }
  }